## neptune-tensorboard 1.0.0

### Fixes
- Export neptune plug-in correctly ([#62](https://github.com/neptune-ai/neptune-tensorboard/pull/62))
- Disable capturing of hardware metrics ([#63](https://github.com/neptune-ai/neptune-tensorboard/pull/63))

### Changes
- Add support to export existing Tensorboard logs via CLI plugin ([#59](https://github.com/neptune-ai/neptune-tensorboard/pull/59/))
- Update integration to work with tensorboardX's SummaryWriter ([#56](https://github.com/neptune-ai/neptune-tensorboard/pull/56))
- Update integration to work with PyTorch's SummaryWriter ([#55](https://github.com/neptune-ai/neptune-tensorboard/pull/55))
- Update integration to work with latest `neptune` client and update the meta-data logging structure ([#51](https://github.com/neptune-ai/neptune-tensorboard/pull/51))

## neptune-tensorboard 1.0.0.pre4

### Fixes
- Export neptune plug-in correctly ([#62](https://github.com/neptune-ai/neptune-tensorboard/pull/62))

## neptune-tensorboard 1.0.0.pre3

### Changes
- Add support to export existing Tensorboard logs via CLI plugin ([#59](https://github.com/neptune-ai/neptune-tensorboard/pull/59/))

## neptune-tensorboard 1.0.0.pre2

### Changes
- Update integration to work with tensorboardX's SummaryWriter ([#56](https://github.com/neptune-ai/neptune-tensorboard/pull/56))

## neptune-tensorboard 1.0.0.pre1

### Changes
- Update integration to work with PyTorch's SummaryWriter ([#55](https://github.com/neptune-ai/neptune-tensorboard/pull/55))

## neptune-tensorboard 1.0.0.pre0

### Changes
- Update integration to work with latest `neptune` client and update the meta-data logging structure ([#51](https://github.com/neptune-ai/neptune-tensorboard/pull/51))

## neptune-tensorboard 0.5.3

### Changes
- Moved `neptune_tensorboard` and `neptune_tensorboard_plugin` packages to `src` directory ([#47](https://github.com/neptune-ai/neptune-tensorboard/pull/47))
